@@ -2,7 +2,7 @@ package HTTP::Message;
 
 use strict;
 use vars qw($VERSION $AUTOLOAD);
-$VERSION = "6.05";
+$VERSION = "6.06";
 
 require HTTP::Headers;
 require Carp;
@@ -671,7 +671,7 @@ sub _parts {
 	my %h = @{$h[0]};
 	if (defined(my $b = $h{boundary})) {
 	    my $str = $self->content;
-	    $str =~ s/\r?\n--\Q$b\E--\r?\n.*//s;
+	    $str =~ s/\r?\n--\Q$b\E--.*//s;
 	    if ($str =~ s/(^|.*?\r?\n)--\Q$b\E\r?\n//s) {
 		$self->{_parts} = [map HTTP::Message->parse($_),
 				   split(/\r?\n--\Q$b\E\r?\n/, $str)]
