@@ -2,7 +2,7 @@ package HTTP::Response;
 
 require HTTP::Message;
 @ISA = qw(HTTP::Message);
-$VERSION = "6.03";
+$VERSION = "6.04";
 
 use strict;
 use HTTP::Status ();
@@ -181,7 +181,6 @@ sub filename
 
 sub as_string
 {
-    require HTTP::Status;
     my $self = shift;
     my($eol) = @_;
     $eol = "\n" unless defined $eol;
@@ -380,7 +379,7 @@ Constructs a new C<HTTP::Response> object describing a response with
 response code $code and optional message $msg.  The optional $header
 argument should be a reference to an C<HTTP::Headers> object or a
 plain array reference of key/value pairs.  The optional $content
-argument should be a string of bytes.  The meaning these arguments are
+argument should be a string of bytes.  The meanings of these arguments are
 described below.
 
 =item $r = HTTP::Response->parse( $str )
