@@ -9,7 +9,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(is_info is_success is_redirect is_error status_message);
 @EXPORT_OK = qw(is_client_error is_server_error);
-$VERSION = "6.00";
+$VERSION = "6.03";
 
 # Note also addition of mnemonics to @EXPORT below
 
@@ -28,6 +28,7 @@ my %StatusCode = (
     205 => 'Reset Content',
     206 => 'Partial Content',
     207 => 'Multi-Status',                    # RFC 2518 (WebDAV)
+    208 => 'Already Reported',		      # RFC 5842
     300 => 'Multiple Choices',
     301 => 'Moved Permanently',
     302 => 'Found',
@@ -53,11 +54,15 @@ my %StatusCode = (
     415 => 'Unsupported Media Type',
     416 => 'Request Range Not Satisfiable',
     417 => 'Expectation Failed',
+    418 => 'I\'m a teapot',		      # RFC 2324
     422 => 'Unprocessable Entity',            # RFC 2518 (WebDAV)
     423 => 'Locked',                          # RFC 2518 (WebDAV)
     424 => 'Failed Dependency',               # RFC 2518 (WebDAV)
     425 => 'No code',                         # WebDAV Advanced Collections
     426 => 'Upgrade Required',                # RFC 2817
+    428 => 'Precondition Required',
+    429 => 'Too Many Requests',
+    431 => 'Request Header Fields Too Large',
     449 => 'Retry with',                      # unofficial Microsoft
     500 => 'Internal Server Error',
     501 => 'Not Implemented',
@@ -69,12 +74,14 @@ my %StatusCode = (
     507 => 'Insufficient Storage',            # RFC 2518 (WebDAV)
     509 => 'Bandwidth Limit Exceeded',        # unofficial
     510 => 'Not Extended',                    # RFC 2774
+    511 => 'Network Authentication Required',
 );
 
 my $mnemonicCode = '';
 my ($code, $message);
 while (($code, $message) = each %StatusCode) {
     # create mnemonic subroutines
+    $message =~ s/I'm/I am/;
     $message =~ tr/a-z \-/A-Z__/;
     $mnemonicCode .= "sub HTTP_$message () { $code }\n";
     $mnemonicCode .= "*RC_$message = \\&HTTP_$message;\n";  # legacy
@@ -128,7 +135,7 @@ HTTP::Status - HTTP Status code processing
 
 I<HTTP::Status> is a library of routines for defining and
 classifying HTTP status codes for libwww-perl.  Status codes are
-used to encode the overall outcome of a HTTP response message.  Codes
+used to encode the overall outcome of an HTTP response message.  Codes
 correspond to those defined in RFC 2616 and RFC 2518.
 
 =head1 CONSTANTS
@@ -149,6 +156,7 @@ tag to import them all.
    HTTP_RESET_CONTENT                   (205)
    HTTP_PARTIAL_CONTENT                 (206)
    HTTP_MULTI_STATUS                    (207)
+   HTTP_ALREADY_REPORTED		(208)
 
    HTTP_MULTIPLE_CHOICES                (300)
    HTTP_MOVED_PERMANENTLY               (301)
@@ -176,11 +184,15 @@ tag to import them all.
    HTTP_UNSUPPORTED_MEDIA_TYPE          (415)
    HTTP_REQUEST_RANGE_NOT_SATISFIABLE   (416)
    HTTP_EXPECTATION_FAILED              (417)
+   HTTP_I_AM_A_TEAPOT			(418)
    HTTP_UNPROCESSABLE_ENTITY            (422)
    HTTP_LOCKED                          (423)
    HTTP_FAILED_DEPENDENCY               (424)
    HTTP_NO_CODE                         (425)
    HTTP_UPGRADE_REQUIRED                (426)
+   HTTP_PRECONDITION_REQUIRED		(428)
+   HTTP_TOO_MANY_REQUESTS		(429)
+   HTTP_REQUEST_HEADER_FIELDS_TOO_LARGE (431)
    HTTP_RETRY_WITH                      (449)
 
    HTTP_INTERNAL_SERVER_ERROR           (500)
@@ -193,6 +205,7 @@ tag to import them all.
    HTTP_INSUFFICIENT_STORAGE            (507)
    HTTP_BANDWIDTH_LIMIT_EXCEEDED        (509)
    HTTP_NOT_EXTENDED                    (510)
+   HTTP_NETWORK_AUTHENTICATION_REQUIRED (511)
 
 =head1 FUNCTIONS
 
@@ -227,11 +240,11 @@ user agent in order to fulfill the request.
 =item is_error( $code )
 
 Return TRUE if C<$code> is an I<Error> status code (4xx or 5xx).  The function
-return TRUE for both client error or a server error status codes.
+returns TRUE for both client and server error status codes.
 
 =item is_client_error( $code )
 
-Return TRUE if C<$code> is an I<Client Error> status code (4xx). This class
+Return TRUE if C<$code> is a I<Client Error> status code (4xx). This class
 of status code is intended for cases in which the client seems to have
 erred.
 
@@ -239,7 +252,7 @@ This function is B<not> exported by default.
 
 =item is_server_error( $code )
 
-Return TRUE if C<$code> is an I<Server Error> status code (5xx). This class
+Return TRUE if C<$code> is a I<Server Error> status code (5xx). This class
 of status codes is intended for cases in which the server is aware
 that it has erred or is incapable of performing the request.
 
@@ -250,5 +263,5 @@ This function is B<not> exported by default.
 =head1 BUGS
 
 For legacy reasons all the C<HTTP_> constants are exported by default
-with the prefix C<RC_>.  It's recommended to use explict imports and
+with the prefix C<RC_>.  It's recommended to use explicit imports and
 the C<:constants> tag instead of relying on this.
